@@ -2,16 +2,28 @@ bullets <- function(...) {
   message(paste0(" * ", ..., collapse = "\n"))
 }
 
-rule <- function(..., pad = "-") {
+rule <- function(..., pad = "-", startup = FALSE) {
   if (nargs() == 0) {
     title <- ""
   } else {
     title <- paste0(...)
   }
   width <- getOption("width") - nchar(title) - 1
-  message(title, " ", paste(rep(pad, width, collapse = "")))
+  text <- paste0(title, " ", paste(rep(pad, width), collapse = ""))
+
+  if (startup) {
+    packageStartupMessage(text)
+  } else {
+    message(text)
+  }
 }
 
+#' List all packages in the tidyverse
+#'
+#' @param include_self Include tidyverse in the list?
+#' @export
+#' @examples
+#' tidyverse_packages()
 tidyverse_packages <- function(include_self = TRUE) {
   raw <- utils::packageDescription("tidyverse")$Imports
   imports <- strsplit(raw, ",")[[1]]
